@@ -1,13 +1,11 @@
 package Net::Amazon::DynamoDB::HighlyAvailable;
 use Net::Amazon::DynamoDB::Table;
 use Carp qw/cluck confess carp croak/;
-use DDP;
-use JSON::XS;
 use Moo;
 use Try::Tiny;
 use DateTime;
 
-our $VERSION="0.02";
+our $VERSION="0.03";
 
 has table       => (is => 'rw', required => 1);
 has hash_key    => (is => 'rw', required => 1);
